# MrPeace

<b> MrPeace </b> is a peaceful command line interface for peacing out when time is limited.

It aims to make the process of writing command line tools quick and fun while also preventing any frustration caused by the inability to implement an intended CLI API.

<img width="50%" height="50%" src='https://i.giphy.com/media/jUwpNzg9IcyrK/giphy.webp'/>

# Virutal Environment

```bash
python3 -m venv venv
```

```bash
source venv/bin/activate
```

```bash
deactivate
```

# Dependencies Package

```bash
pip3 freeze> requirements.txt
```

# Installation

```bash
pip3 install -r requirements.txt
```

# Remark

To activate SHEBANG.

```bash
chmod +x *.py
```

# Editable

```
pip3 install --editable .
```
